/*-------------------------------------------------------------------------
		TRAMECAD  
		LIBRARY OPENSCAD FOR STEEL MODELLING
		Developed by Paulo C. Ormonde
		Blog: http://trameestruturas.blogspot.com.br
		E-mail: ormonde.paulo@gmail.com

//-------------------------------------------------------------------------
/* IBEAM - MODULE TRAME3D FOR I SECTION TUBES MODELING

 1 - vbeam (d,bf, tf, tw, lo, zrot, z) 

 2 - hbeam (d,bf, tf, tw, lo, rot, zrot, z) 
          
 3 - ibeam (d, bf, tf, tw, rot, x1, y1, z1, x2, y2, z2)

P.S.: rot is the rotation around the longitudinal axis.

*/

//-------------------------------------------------------------------------
// EXAMPLE
//-------------------------------------------------------------------------
/* color("SteelBlue")
vbeam(150,100,5,5,2000,135,0);
translate([1000,1000,0])
color("OrangeRed")
vbeam(150,100,5,5,2000,45,0);

color("Silver"){
hbeam(100,100,5,5,1400,0,45,1000);
hbeam(100,100,5,5,1400,90,45,1950);
}

ibeam(100,100,5,5,90,0,0,0,1000,1000,1000);
color("Red")
ibeam(100,100,5,5,90,0,0,0,0,0,1200);
color("Red")
ibeam(100,100,5,5,90,0,1000,0,0,1000,2200);
color("Red")
ibeam(100,100,5,5,90,1000,1000,0,1000,1000,1200);
color("Red")
ibeam(100,100,5,5,90,1000,1000,1200,0,1000,2200);

color("Orange")
ibeam(100,100,5,5,90,0,1000,1000,1000,1000,1000);
color("Orange")
ibeam(100,100,5,5,90,0,0,1000,0,1000,1000);
color("Orange")
ibeam(100,100,5,5,90,1000,1000,1000,1000,0,1000);
color("Orange")
ibeam(100,100,5,5,90,1000,0,1000,0,0,1000);


color("SteelBlue"){
ibeam(100,100,5,5,90,0,0,0,1000,1000,1000);
ibeam(100,100,5,5,90,0,1000,0,1000,1000,1000);
ibeam(100,100,5,5,90,1000,1000,1000,0,0,1000);
ibeam(100,100,5,5,0,1000,0,1000,0,1000,1000);
}
*/
//-------------------------------------------------------------------------
// HBEAM - I BEAM ALIGNED WITH THE HORIZONTAL PLANE
//-------------------------------------------------------------------------
module   hbeam(d,bf, tf, tw, lo, rot, zrot, z){
 rotate ([0,0,zrot]){   
	 translate([0,0,z]) {   
				 hisec(d, bf, tf, tw, lo,rot);
   }
 }
}



//-------------------------------------------------------------------------
// VBEAM - I BEAM ALIGNED WITH Z-AXIS
//-------------------------------------------------------------------------
module vbeam(d,bf, tf, tw, lo, zrot, z){
	translate([0,0,lo/2 + z]){
	 visec(d, bf, tf, tw, lo, zrot);
  }
}

//-------------------------------------------------------------------------
// IBEAM - I SECTION BY 2 POINTS
//-------------------------------------------------------------------------
module ibeam(d, bf, tf, tw, rot, x1, y1, z1, x2, y2, z2){
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
ht = sqrt(pow(dx,2) + pow(dy,2) + pow(dz,2));
dxy = sqrt(pow(dx,2) + pow(dy,2)); // X-Y plane projection

//angzy=90-atan(dz/dxy);
//angz=atan(dy/dx);
	translate([x1 + dx/2, y1 + dy/2, z1 + dz/2]){

										if (dx > 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
                                               visec(d, bf, tf, tw, ht,rot); 
													} //rot
										    } //if
										if (dx < 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),180-abs(atan(dy/dx))]){
                                               visec(d, bf, tf, tw, ht,rot); 
													} //rot
										    } //if
										if (dx < 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),180+abs(atan(dy/dx))]){
                                                visec(d, bf, tf, tw, ht,rot); 
													} //rot
										    } //if
										if (dx > 0 && dy <=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx)) ]){
                                               visec(d, bf, tf, tw, ht,rot); 
													} //rot
									  } //if
										if (dx == 0 && dy !=0){
                                       rotate ([0,(90-atan(dz/dxy)),90 ]){
                                               visec(d, bf, tf, tw, ht,rot); 
													} //rot
									  } //if
                              if (dx == 0 && dy == 0){
                                    visec(d, bf, tf, tw, ht,rot); 
                              } //if
      } //translate
}    //end module






//-------------------------------------------------------------------------
// VISEC 
//-------------------------------------------------------------------------
module visec(d, bf, tf, tw, lo, rot){
 rotate ([0,0,rot]){
    union() {		
     cube(size = [tw,d-2*tf,lo], center=true);
        translate([0,(d/2)-(tf/2),0])
           cube(size = [bf,tf,lo], center=true); 
             translate([0,-(d/2)+(tf/2),0])
                cube(size = [bf,tf,lo], center=true);
        }
    }
}

//-------------------------------------------------------------------------
// HISEC  
//-------------------------------------------------------------------------
module hisec(d, bf, tf, tw, lo,rot){

rotate ([rot,0,0]){
  translate([0,0,-d/2]){
	    union() {	
	  translate([0,-tw/2,tf])	
	     cube(size = [lo,tw,d-2*tf], center=false);
	
	        translate([0,-bf/2,0])
	           cube(size = [lo,bf,tf], center=false); 
	
	             translate([0,-bf/2,d-tf])
	                cube(size = [lo,bf,tf], center=false);
      }
    }
  }
}







