/*-------------------------------------------------------------------------
		TRAMECAD  
		LIBRARY OPENSCAD FOR STEEL MODELLING
		Developed by Paulo C. Ormonde
		Blog: http://trameestruturas.blogspot.com.br
		E-mail: ormonde.paulo@gmail.com

//-------------------------------------------------------------------------
/* DANGI - MODULE TRAME3D FOR DOUBLE ANGLE INTERNAL SECTION
          
  dangi (b, t, esp, rot, x1, y1, z1, x2, y2, z2)

P.S.: rot is the rotation around the longitudinal axis.
       

*/

//-------------------------------------------------------------------------
// EXAMPLE
//-------------------------------------------------------------------------
/*
color("Red")
dangi(50,10,10,90,0,0,0,0,0,1200);
color("Red")
dangi(100,10,10,90,0,1000,0,0,1000,2200);
color("Red")
dangi(100,10,10,90,1000,1000,0,1000,1000,1200);
color("Red")
dangi(100,10,10,90,1000,1000,1200,0,1000,2200);

color("Orange")
dangi(90,10,50,90,0,1000,1000,1000,1000,1000);
color("Orange")
dangi(90,10,50,90,0,0,1000,0,1000,1000);
color("Orange")
dangi(90,10,50,90,1000,1000,1000,1000,0,1000);
color("Orange")
dangi(90,10,50,90,1000,0,1000,0,0,1000);
color("SteelBlue"){
dangi(50,5,50,90,0,0,0,1000,1000,1000);
dangi(50,5,50,90,1000,1000,1000,0,0,1000);
dangi(50,5,50,90,1000,1000,0,0,0,1000);
}

color("Cyan"){
dangi(50,5,50,90,0,1000,0,1000,1000,1000);
dangi(50,5,50,90,1000,0,0,1000,1000,1000);
dangi(50,5,50,90,1000,0,0,0,0,1000);
}
*/

//-------------------------------------------------------------------------
// ANGLE - ANGLE SECTION BY 2 POINTS
//-------------------------------------------------------------------------
module dangi(b, t, esp, rot, x1, y1, z1, x2, y2, z2){
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
ht = sqrt(pow(dx,2) + pow(dy,2) + pow(dz,2));
dxy = sqrt(pow(dx,2) + pow(dy,2)); // X-Y plane projection

//angzy=0;
//angz=0;

//angzy=90-atan(dz/dxy);

//angz=atan(dy/dx);


	translate([x1 + dx/2, y1 + dy/2, z1 + dz/2]){

										if (dx > 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
                                               vaisec(b,t,esp,ht, rot); 
													} //rot
										    } //if
										if (dx < 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),180-abs(atan(dy/dx))]){
                                               vaisec(b,t,esp,ht, rot);
													} //rot
										    } //if
										if (dx < 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),180+abs(atan(dy/dx))]){
                                                vaisec(b,t,esp,ht, rot); 
													} //rot
										    } //if
										if (dx > 0 && dy <=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx)) ]){
                                               vaisec(b,t,esp,ht, rot); 
													} //rot
									  } //if
										if (dx == 0 && dy !=0){
                                       rotate ([0,(90-atan(dz/dxy)),90 ]){
                                               vaisec(b,t,esp,ht, rot); 
													} //rot
									  } //if
										if (dx == 0 && dy == 0){
                                               vaisec(b,t,esp,ht, rot); 
									  } //if
      } //translate
}    //end module






//-------------------------------------------------------------------------
// VRSEC 
//-------------------------------------------------------------------------
module vaisec(b,t,esp,lo, rot){
 rotate ([0,0,rot]){
  union(){
	  translate([-(b+esp)/2, 0, 0]){
	    difference() {		
	     cube(size = [b,b,lo], center=true);
	      translate([t, t, 0])
	       cube(size = [b,b,1.10*lo], center=true);  
	        }
	      }       
	  translate([(b+esp)/2, 0, 0]){   
    rotate ([0,0,90]){   
	    difference() {		
	     cube(size = [b,b,lo], center=true);
	      translate([t, t, 0])
	       cube(size = [b,b,1.10*lo], center=true);  
	        }
         }
	    }
    } //union
  }
}










