/*-------------------------------------------------------------------------
		TRAMECAD  
		LIBRARY OPENSCAD FOR STEEL MODELLING
		Developed by Paulo C. Ormonde
		Blog: http://trameestruturas.blogspot.com.br
		E-mail: ormonde.paulo@gmail.com

//-------------------------------------------------------------------------
/* RBEAM - MODULE TRAME3D FOR RETANGULAR SECTIONS 
          
  rbeam (b, h, rot, x1, y1, z1, x2, y2, z2)

P.S.: rot is the rotation around the longitudinal axis.

*/

//-------------------------------------------------------------------------
// EXAMPLE
//-------------------------------------------------------------------------
/*
color("Red")
rbeam(100,200,0,0,0,0,0,0,1200);
color("Red")
rbeam(100,200,90,0,1000,0,0,1000,2200);
color("Red")
rbeam(100,200,90,1000,1000,0,1000,1000,1200);
color("Red")
rbeam(100,200,90,1000,1000,1200,0,1000,2200);

color("Orange")
rbeam(90,200,90,0,1000,1000,1000,1000,1000);
color("Orange")
rbeam(90,200,90,0,0,1000,0,1000,1000);
color("Orange")
rbeam(90,200,90,1000,1000,1000,1000,0,1000);
color("Orange")
rbeam(90,200,90,1000,0,1000,0,0,1000);
color("SteelBlue"){
rbeam(50,100,90,0,0,0,1000,1000,1000);
rbeam(50,100,90,1000,1000,1000,0,0,1000);
rbeam(50,100,90,1000,1000,0,0,0,1000);
}

color("Cyan"){
rbeam(50,100,90,0,1000,0,1000,1000,1000);
rbeam(50,100,90,1000,0,0,1000,1000,1000);
rbeam(50,100,90,1000,0,0,0,0,1000);
}

*/
//-------------------------------------------------------------------------
// RBEAM - RECTANGULAR SECTION BY 2 POINTS
//-------------------------------------------------------------------------
module rbeam(b, h, rot, x1, y1, z1, x2, y2, z2){
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
ht = sqrt(pow(dx,2) + pow(dy,2) + pow(dz,2));
dxy = sqrt(pow(dx,2) + pow(dy,2)); // X-Y plane projection

//angzy=0;
//angz=0;

//angzy=90-atan(dz/dxy);

//angz=atan(dy/dx);


	translate([x1 + dx/2, y1 + dy/2, z1 + dz/2]){

										if (dx > 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
                                               vrsec(b,h,ht,rot); 
													} //rot
										    } //if
										if (dx < 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),180-abs(atan(dy/dx))]){
                                               vrsec(b,h,ht,rot);
													} //rot
										    } //if
										if (dx < 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),180+abs(atan(dy/dx))]){
                                                vrsec(b,h,ht,rot); 
													} //rot
										    } //if
										if (dx > 0 && dy <=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx)) ]){
                                               vrsec(b,h,ht, rot); 
													} //rot
									  } //if
										if (dx == 0 && dy !=0){
                                       rotate ([0,(90-atan(dz/dxy)),90 ]){
                                               vrsec(b,h,ht, rot); 
													} //rot
									  } //if
										if (dx == 0 && dy == 0){
                                               vrsec(b,h,ht, rot); 
									  } //if
      } //translate
}    //end module






//-------------------------------------------------------------------------
// VRSEC 
//-------------------------------------------------------------------------
module vrsec(b,h,lo, rot){
 rotate ([0,0,rot]){
     cube(size = [b,h,lo], center=true);
    }
}









