/* TUBE - MODULE TRAMECAD FOR CIRCULAR SECTION TUBES MODELING

 1 - vtube ( øext, thickness, height, z position) 

 2 - htube ( øext, thickness, height, z position) 
          
 3 - tub (øext, thickness, x1, y1, z1, x2, y2, z2)

 4 - rod (ø rod, x1, y1, z1, x2, y2, z2) 

 5 - xrod (ø rod, x1, y1, z1, x2, y2, z2)   

*/

//-------------------------------------------------------------------------
// EXAMPLE
//-------------------------------------------------------------------------
/*
for (j=[0:1]){
 for (i = [0:1]){
  translate([2000*i,2000*j,0]){ color("OrangeRed") vtube(150,3,2000,0);
                                color("steelBlue") htube(150,5,2000,2000,90*i-90*j+180*i*j);
                              }
    tub(100,3, 2000*i, 2000*j, 2000, 1000,1000,3000); 
    tub(100,3, 2000*i, 2000*j, 2000, 1000,1000,1000); 
  }
 }
*/

/*
tub(100,3,0,0,0,1000,1000,1000);
color("Red")
tub(100,3,0,0,0,0,0,1200);
color("Red")
tub(100,3,0,1000,0,0,1000,2200);
color("Red")
tub(100,3,1000,1000,0,1000,1000,1200);
color("Red")
tub(100,3,1000,1000,1200,0,1000,2200);

color("Orange")
tub(100,3,0,1000,1000,1000,1000,1000);
color("Orange")
tub(100,3,0,0,1000,0,1000,1000);
color("Orange")
tub(150,3,1000,1000,1000,1000,0,1000);
color("Orange")
tub(100,3,1000,0,1000,0,0,1000);

color("SteelBlue"){
tub(100,3,0,0,0,1000,1000,1000);
tub(100,3,0,1000,0,1000,1000,1000);
tub(100,3,1000,1000,1000,0,0,1000);
}
*/

/*
color("Red")
rod(30,0,0,0,0,0,1200);
color("Red")
rod(30,0,1000,0,0,1000,2200);
color("Red")
rod(30,1000,1000,0,1000,1000,1200);
color("Red")
rod(30,1000,1000,1200,0,1000,2200);

color("Orange")
rod(30,0,1000,1000,1000,1000,1000);
color("Orange")
rod(30,0,0,1000,0,1000,1000);
color("Orange")
rod(30,1000,1000,1000,1000,0,1000);
color("Orange")
rod(30,1000,0,1000,0,0,1000);

color("SteelBlue"){
rod(30,0,0,0,1000,1000,1000);
rod(30,0,1000,0,1000,1000,1000);
rod(30,1000,1000,1000,0,0,1000);
}

*/
//-------------------------------------------------------------------------
// HTUBE - TUBE ALIGNED WITH THE HORIZONTAL PLANE
//-------------------------------------------------------------------------
module htube(dt,tt,ht,zt,angt){
re=dt/2;
ri=re-tt;
dx=cos(angt)*ht/2;
dy=sin(angt)*ht/2;
translate([dx,dy,zt]){
rotate([0,90,angt]){
		difference(){
		cylinder(  ht, re, re,center=true);
		cylinder( ht*2,ri,ri,center=true);
		}
	}
  }
}



//-------------------------------------------------------------------------
// VTUBE - TUBE ALIGNED WITH Z-AXIS
//-------------------------------------------------------------------------
module vtube(dt,tt,ht,zt){
re=dt/2;
ri=re-tt;
difference(){
translate([0, 0, zt])
cylinder(  ht, re, re,false);
translate([0, 0, zt-ht])
cylinder(  ht*3,ri,ri,false);
}
}

//-------------------------------------------------------------------------
// TUB - 3D TUBE BY 2 POINTS
//-------------------------------------------------------------------------
module tub(dt,tt, x1, y1, z1, x2, y2, z2){
re=dt/2;
ri=re-tt;
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
ht = sqrt(pow(dx,2) + pow(dy,2) + pow(dz,2));
dxy = sqrt(pow(dx,2) + pow(dy,2)); // X-Y plane projection

//angzy=90-atan(dz/dxy);
//angz=atan(dy/dx);

	translate([x1, y1, z1]){

										if (dx >0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff
													} //rot
										    } //if
										if (dx < 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),180-abs(atan(dy/dx))]){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff
													} //rot
										    } //if
										if (dx < 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),180+abs(atan(dy/dx))]){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff
													} //rot
										    } //if
										if (dx > 0 && dy <=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx)) ]){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff
													} //rot
										    } //if
										if (dx == 0 && dy > 0){
                                       rotate ([0,(90-atan(dz/dxy)),90 ]){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff
													} //rot
									  } //if
										if (dx == 0 && dy < 0){
                                       rotate ([0,(90-atan(dz/dxy)),-90 ]){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff
													} //rot
									  } //if
                              if (dx == 0 && dy == 0){
													   difference(){
															cylinder(  ht, re, re,false);
										               translate([0, 0, -ht/4])
															cylinder(  ht*2,ri,ri,false);
										            } //diff; 
                              } //if
   } //translate
}    //end module





//-------------------------------------------------------------------------
// ROD - 3D ROD BY 2 POINTS
//-------------------------------------------------------------------------
module rod(dt, x1, y1, z1, x2, y2, z2){
re=dt/2;
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
ht = sqrt(pow(dx,2) + pow(dy,2) + pow(dz,2));
dxy = sqrt(pow(dx,2) + pow(dy,2)); // X-Y plane projection

//angzy=90-atan(dz/dxy);
//angz=atan(dy/dx);

	translate([x1, y1, z1]){

										if (dx > 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
															cylinder(  ht, re, re,false);
												} //rot
										    } //if
										if (dx < 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),180-abs(atan(dy/dx))]){
															cylinder(  ht, re, re,false);
													} //rot
										    } //if
										if (dx < 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),180+abs(atan(dy/dx))]){
															cylinder(  ht, re, re,false);
													} //rot
										    } //if
										if (dx > 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
															cylinder(  ht, re, re,false);
													} //rot
										    } //if
										if (dx == 0 && dy > 0){
                                       rotate ([0,(90-atan(dz/dxy)),90 ]){
															cylinder(  ht, re, re,false);
													} //rot
									  } //if
										if (dx == 0 && dy < 0){
                                       rotate ([0,(90-atan(dz/dxy)),-90 ]){
															cylinder(  ht, re, re,false);
													} //rot
									  } //if
                              if (dx == 0 && dy == 0){
															cylinder(  ht, re, re,false);
                              } //if  
   } //translate
}    //end module


//-------------------------------------------------------------------------
// XROD - 3D ROD SYSTEM 
//-------------------------------------------------------------------------
module xrod(dt, x1, y1, z1, x2, y2, z2){
rod(dt,x1,y1,z1, x2, y2, z2);
rod(dt,x1,y1,z2, x2, y2, z1);
}



