/*-------------------------------------------------------------------------
		TRAMECAD  
		LIBRARY OPENSCAD FOR STEEL MODELLING
		Developed by Paulo C. Ormonde
		Blog: http://trameestruturas.blogspot.com.br
		E-mail: ormonde.paulo@gmail.com

//-------------------------------------------------------------------------
/* UBEAM - MODULE TRAME3D FOR U SECTION
          
  ubeam (b, h, t, rot, x1, y1, z1, x2, y2, z2)

P.S.: rot is the rotation around the longitudinal axis.

*/

//-------------------------------------------------------------------------
// EXAMPLE
//-------------------------------------------------------------------------
/*
color("Red")
ubeam(50,100,10,90,0,0,0,0,0,1200);
color("Red")
ubeam(100,100,10,90,0,1000,0,0,1000,2200);
color("Red")
ubeam(100,100,10,90,1000,1000,0,1000,1000,1200);
color("Red")
ubeam(100,100,10,90,1000,1000,1200,0,1000,2200);

color("Orange")
ubeam(90,200,9,90,0,1000,1000,1000,1000,1000);
color("Orange")
ubeam(90,200,9,90,0,0,1000,0,1000,1000);
color("Orange")
ubeam(90,200,9,90,1000,1000,1000,1000,0,1000);
color("Orange")
ubeam(90,200,9,90,1000,0,1000,0,0,1000);
color("SteelBlue"){
ubeam(50,100,5,90,0,0,0,1000,1000,1000);
ubeam(50,100,5,90,1000,1000,1000,0,0,1000);
ubeam(50,100,5,90,1000,1000,0,0,0,1000);
}

color("Cyan"){
ubeam(50,100,5,90,0,1000,0,1000,1000,1000);
ubeam(50,100,5,90,1000,0,0,1000,1000,1000);
ubeam(50,100,5,90,1000,0,0,0,0,1000);
}

*/
//-------------------------------------------------------------------------
// ANGLE - ANGLE SECTION BY 2 POINTS
//-------------------------------------------------------------------------
module ubeam(b, h, t, rot, x1, y1, z1, x2, y2, z2){
dx = x2-x1;
dy = y2-y1;
dz = z2-z1;
ht = sqrt(pow(dx,2) + pow(dy,2) + pow(dz,2));
dxy = sqrt(pow(dx,2) + pow(dy,2)); // X-Y plane projection

//angzy=0;
//angz=0;

//angzy=90-atan(dz/dxy);

//angz=atan(dy/dx);


	translate([x1 + dx/2, y1 + dy/2, z1 + dz/2]){

										if (dx > 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx))]){
                                               vusec(b,h,t,ht,rot); 
													} //rot
										    } //if
										if (dx < 0 && dy >=0){
                                       rotate ([0,(90-atan(dz/dxy)),180-abs(atan(dy/dx))]){
                                               vusec(b,h,t,ht,rot);
													} //rot
										    } //if
										if (dx < 0 && dy <0){
                                       rotate ([0,(90-atan(dz/dxy)),180+abs(atan(dy/dx))]){
                                                vusec(b,h,t,ht,rot); 
													} //rot
										    } //if
										if (dx > 0 && dy <=0){
                                       rotate ([0,(90-atan(dz/dxy)),(atan(dy/dx)) ]){
                                               vusec(b,h,t,ht, rot); 
													} //rot
									  } //if
										if (dx == 0 && dy !=0){
                                       rotate ([0,(90-atan(dz/dxy)),90 ]){
                                               vusec(b,h,t,ht, rot); 
													} //rot
									  } //if
										if (dx == 0 && dy == 0){
                                               vusec(b,h,t,ht, rot); 
									  } //if
      } //translate
}    //end module






//-------------------------------------------------------------------------
// VRSEC 
//-------------------------------------------------------------------------
module vusec(b,h,t,lo, rot){
 rotate ([0,0,rot]){
    difference() {		
     cube(size = [b,h,lo], center=true);
      translate([t, 0, 0])
       cube(size = [b,h-2*t,1.10*lo], center=true);  
        }
    }
}









